lyricstools.LyricSpace
======================

.. inheritance-diagram:: abjad.tools.lyricstools.LyricSpace.LyricSpace.LyricSpace
   :private-bases:

.. autoclass:: abjad.tools.lyricstools.LyricSpace.LyricSpace.LyricSpace

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.lyricstools.LyricSpace.LyricSpace.LyricSpace.duration_in_seconds

    Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.lyricstools.LyricSpace.LyricSpace.LyricSpace.format

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.LyricSpace.LyricSpace.LyricSpace.leaf_index

    Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.lyricstools.LyricSpace.LyricSpace.LyricSpace.multiplied_duration

    Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.lyricstools.LyricSpace.LyricSpace.LyricSpace.override

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.LyricSpace.LyricSpace.LyricSpace.parent

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.LyricSpace.LyricSpace.LyricSpace.preprolated_duration

    Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.lyricstools.LyricSpace.LyricSpace.LyricSpace.prolated_duration

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.LyricSpace.LyricSpace.LyricSpace.prolation

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.LyricSpace.LyricSpace.LyricSpace.set

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.LyricSpace.LyricSpace.LyricSpace.spanners

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.LyricSpace.LyricSpace.LyricSpace.start_offset

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.LyricSpace.LyricSpace.LyricSpace.start_offset_in_seconds

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.LyricSpace.LyricSpace.LyricSpace.stop_offset

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.LyricSpace.LyricSpace.LyricSpace.stop_offset_in_seconds

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.lyricstools.LyricSpace.LyricSpace.LyricSpace.duration_multiplier

    Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.lyricstools.LyricSpace.LyricSpace.LyricSpace.written_duration

    Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.lyricstools.LyricSpace.LyricSpace.LyricSpace.written_pitch_indication_is_at_sounding_pitch

    Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.lyricstools.LyricSpace.LyricSpace.LyricSpace.written_pitch_indication_is_nonsemantic

    Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

Special Methods
---------------

.. automethod:: abjad.tools.lyricstools.LyricSpace.LyricSpace.LyricSpace.__and__

    Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. automethod:: abjad.tools.lyricstools.LyricSpace.LyricSpace.LyricSpace.__delattr__

    Inherited from `__builtin__.object`

.. automethod:: abjad.tools.lyricstools.LyricSpace.LyricSpace.LyricSpace.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lyricstools.LyricSpace.LyricSpace.LyricSpace.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lyricstools.LyricSpace.LyricSpace.LyricSpace.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lyricstools.LyricSpace.LyricSpace.LyricSpace.__hash__

    Inherited from `__builtin__.object`

.. automethod:: abjad.tools.lyricstools.LyricSpace.LyricSpace.LyricSpace.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lyricstools.LyricSpace.LyricSpace.LyricSpace.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lyricstools.LyricSpace.LyricSpace.LyricSpace.__mul__

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. automethod:: abjad.tools.lyricstools.LyricSpace.LyricSpace.LyricSpace.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lyricstools.LyricSpace.LyricSpace.LyricSpace.__or__

    Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. automethod:: abjad.tools.lyricstools.LyricSpace.LyricSpace.LyricSpace.__repr__

    Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. automethod:: abjad.tools.lyricstools.LyricSpace.LyricSpace.LyricSpace.__rmul__

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. automethod:: abjad.tools.lyricstools.LyricSpace.LyricSpace.LyricSpace.__setattr__

    Inherited from `__builtin__.object`

.. automethod:: abjad.tools.lyricstools.LyricSpace.LyricSpace.LyricSpace.__str__

    Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. automethod:: abjad.tools.lyricstools.LyricSpace.LyricSpace.LyricSpace.__sub__

    Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. automethod:: abjad.tools.lyricstools.LyricSpace.LyricSpace.LyricSpace.__xor__

    Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`
